@@ -46,7 +46,10 @@
 
 dicom.browser <- function(dicom.raw.data, nbTAG = 0, stop.tag = "", stop.level= 0, 
                           full.info = FALSE, tag.dictionary = dicom.tag.dictionary ()){
-
+  if (!is.raw(dicom.raw.data)) {
+    warning ("dicom.raw.data should be raw data :).")
+    return (NULL)
+  }
   L <- .dicombrowser (dicom.raw.data, tag.dictionary, nbTAG = nbTAG,
                          stop_tag=stop.tag, stop_level= stop.level, 
                          full_info = full.info, verbose = FALSE)
